/**
 * Run "ui".
 * @memberof module:/lib
 * @function ui
 * @param {string} name - Name of ui to generate..
 * @param {object} [options] - Optional settings.
 * @param {boolean} [options.verbose=false] - Show verbose logs.
 * @param {string} [options.configuration] - Pathname of Apemanfile.
 * @param {function} [callback] - Callback when done.
 */

"use strict";

var argx = require('argx'),
    async = require('async'),
    apemanfile = require('apemanfile'),
    UiRunner = require('./ui_runner');

/** @lends ui */
function ui(name, options, callback) {
    var args = argx(arguments);
    name = args.shift();
    callback = args.pop('function') || argx.noop;
    options = args.pop('object') || {};

    async.waterfall([
        function (callback) {
            apemanfile.load(options.configuration, callback);
        },
        function (apemanfile, callback) {
            var runner = new UiRunner({
                verbose: options.verbose || false,
                configuration: options.configuration,
                apemanfile: apemanfile
            });
            runner.run(name, callback);
        }
    ], callback);

}

module.exports = ui;