/**
 * Logger for ui.
 * @memberof module:apeman-ui/lib
 * @inner
 * @augments module:apeman-commons-logging/lib~ConsoleLogger
 * @constructor UiLogger
 * @param {object} config - Logger configuration.
 * @param {string} [config.name] - Name of log.
 * @param {boolean} [config.verbose] - Should emit verbose.
 */

"use strict";

var ConsoleLogger = require('apeman-commons-logging/lib/console_logger'),
    util = require('util');

module.exports = function (config) {
    config = config || {};
    var name = config.name || 'apeman-ui',
        verbose = !!config.verbose;
    return new ConsoleLogger({
        verbose: verbose,
        PREFIX: util.format('[%s] ', name),
        /**
         * Print about ui start.
         */
        printUiStart: function () {
            var s = this;
            s.info('Start UI building..');
        },
        /**
         * Print about ui done.
         */
        printUiDone: function () {
            var s = this;
            s.info('..building UI done!');
        },
        /**
         * Print about ui fail.
         * @param {Error} err
         */
        printUiFailed: function (err) {
            var s = this;
            s.error(err.stack || err.msg || err);
        },
        /**
         * Print about config.
         * @param {object} config - Config to log.
         */
        printConfig: function (config) {
            var s = this;
            s.trace("%s", config);
        }
    });
};
